@@ -86,6 +86,8 @@ enum mlx5dv_context_comp_mask {
 	MLX5DV_CONTEXT_MASK_DCI_STREAMS		= 1 << 11,
 	MLX5DV_CONTEXT_MASK_WR_MEMCPY_LENGTH	= 1 << 12,
 	MLX5DV_CONTEXT_MASK_CRYPTO_OFFLOAD	= 1 << 13,
+	MLX5DV_CONTEXT_MASK_MAX_DC_RD_ATOM	= 1 << 14,
+	MLX5DV_CONTEXT_MASK_REG_C0		= 1 << 15,
 };
 
 struct mlx5dv_cqe_comp_caps {
@@ -185,6 +187,7 @@ struct mlx5dv_sig_caps {
 enum mlx5dv_crypto_engines_caps {
 	MLX5DV_CRYPTO_ENGINES_CAP_AES_XTS = 1 << 0,
 	MLX5DV_CRYPTO_ENGINES_CAP_AES_XTS_SINGLE_BLOCK = 1 << 1,
+	MLX5DV_CRYPTO_ENGINES_CAP_AES_XTS_MULTI_BLOCK = 1 << 2,
 };
 
 enum mlx5dv_crypto_wrapped_import_method_caps {
@@ -231,6 +234,9 @@ struct mlx5dv_context {
 	struct mlx5dv_dci_streams_caps dci_streams_caps;
 	size_t max_wr_memcpy_length;
 	struct mlx5dv_crypto_caps crypto_caps;
+	uint64_t max_dc_rd_atom;
+	uint64_t max_dc_init_rd_atom;
+	struct mlx5dv_reg reg_c0;
 };
 
 enum mlx5dv_context_flags {
@@ -283,6 +289,8 @@ enum mlx5dv_mkey_init_attr_flags {
 	MLX5DV_MKEY_INIT_ATTR_FLAGS_INDIRECT = 1 << 0,
 	MLX5DV_MKEY_INIT_ATTR_FLAGS_BLOCK_SIGNATURE = 1 << 1,
 	MLX5DV_MKEY_INIT_ATTR_FLAGS_CRYPTO = 1 << 2,
+	MLX5DV_MKEY_INIT_ATTR_FLAGS_UPDATE_TAG = 1 << 3,
+	MLX5DV_MKEY_INIT_ATTR_FLAGS_REMOTE_INVALIDATE = 1 << 4,
 };
 
 struct mlx5dv_mkey_init_attr {
@@ -1271,7 +1279,7 @@ struct mlx5_wqe_av {
 	uint8_t		fl_mlid;
 	__be16		rlid;
 	uint8_t		reserved0[4];
-	uint8_t		rmac[6];
+	uint8_t		rmac[ETHERNET_LL_SIZE];
 	uint8_t		tclass;
 	uint8_t		hop_limit;
 	__be32		grh_gid_fl;
@@ -1518,7 +1526,7 @@ void mlx5dv_set_dgram_seg(struct mlx5_wqe_datagram_seg *seg,
 	seg->av.stat_rate_sl	= stat_rate_sl;
 	seg->av.fl_mlid		= fl_mlid;
 	seg->av.rlid		= htobe16(rlid);
-	memcpy(seg->av.rmac, rmac, 6);
+	memcpy(seg->av.rmac, rmac, ETHERNET_LL_SIZE);
 	seg->av.tclass		= tclass;
 	seg->av.hop_limit	= hop_limit;
 	seg->av.grh_gid_fl	= htobe32(grh_gid_fi);
@@ -1742,12 +1750,17 @@ struct mlx5dv_devx_umem {
 struct mlx5dv_devx_umem *
 mlx5dv_devx_umem_reg(struct ibv_context *ctx, void *addr, size_t size, uint32_t access);
 
+enum  mlx5dv_devx_umem_in_mask {
+	MLX5DV_UMEM_MASK_DMABUF = 1 << 0,
+};
+
 struct mlx5dv_devx_umem_in {
 	void *addr;
 	size_t size;
 	uint32_t access;
 	uint64_t pgsz_bitmap;
 	uint64_t comp_mask;
+	int dmabuf_fd;
 };
 
 struct mlx5dv_devx_umem *
